Module: Starapi

Defined in:
lib/starapi/soap_service_facade/execute_sp.rb,
lib/starapi.rb,
lib/starapi/version.rb,
lib/starapi/soap_service_facade/base.rb,
lib/starapi/soap_service_target/base.rb,
lib/generators/starapi/install_generator.rb,
lib/starapi/soap_service_facade/soap_error.rb,
lib/starapi/soap_service_target/price_quote.rb

Overview

Xml Structure #########################################################

Request

GU_sp_DR_Price_Quote 7827 DUKE_OH R 2012-12-05

Response

0001 FE_OHED Ohio Electric - Residential R Ohio Res - 1 Yr Fixed - Dec 12 2012-12-01 2012-12-31 0.0965 kWh 0.0984 The Price to Compare for Ohio Electric was derived assuming a 750kWh average monthly consumption. Your actual Price to Compare could vary slightly based on your actual usage.

Defined Under Namespace

Modules: Generators, SoapServiceFacade, SoapServiceTarget

Constant Summary collapse

VERSION =
"0.0.3"
@@namespace =
"http://www.example.com/RS/webservices/"
@@service_url =
'http://example/READiDataExchange/WSRSDataExchange.asmx'
@@user =
"user"
@@password =
"password"

Class Method Summary collapse

Class Method Details

.setup {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:

  • _self (Starapi)

    the object that the method was called on



18
19
20
# File 'lib/starapi.rb', line 18

def setup
  yield self
end